@@ -1,6 +1,7 @@
 """ Loading Raw data """
 import logging
 from dataclasses import dataclass
+from datetime import datetime
 from numbers import Number
 from pathlib import Path
 from typing import List, Tuple, Union
@@ -14,7 +15,7 @@ from nowcasting_dataset.data_sources.data_source import DataSource
 from nowcasting_dataset.data_sources.metadata.metadata_model import SpaceTimeLocation
 from nowcasting_dataset.data_sources.sun.raw_data_load_save import load_from_zarr, x_y_to_name
 from nowcasting_dataset.data_sources.sun.sun_model import Sun
-from nowcasting_dataset.geospatial import calculate_azimuth_and_elevation_angle
+from nowcasting_dataset.geospatial import calculate_azimuth_and_elevation_angle, osgb_to_lat_lon
 
 logger = logging.getLogger(__name__)
 
@@ -24,6 +25,8 @@ class SunDataSource(DataSource):
     """Add azimuth and elevation angles of the sun."""
 
     zarr_path: Union[str, Path]
+    load_live: bool = False
+    elevation_limit: int = 10
 
     def __post_init__(self):
         """Post Init"""
@@ -37,7 +40,8 @@ class SunDataSource(DataSource):
 
     def check_input_paths_exist(self) -> None:
         """Check input paths exist.  If not, raise a FileNotFoundError."""
-        nd_fs_utils.check_path_exists(self.zarr_path)
+        if not self.load_live:
+            nd_fs_utils.check_path_exists(self.zarr_path)
 
     def get_example(self, location: SpaceTimeLocation) -> xr.Dataset:
         """
@@ -64,26 +68,40 @@ class SunDataSource(DataSource):
         start_dt = self._get_start_dt(t0_datetime_utc)
         end_dt = self._get_end_dt(t0_datetime_utc)
 
-        # The names of the columns get truncated when saving, therefore we need to look for the
-        # name of the columns near the location we are looking for
-        locations = np.array(
-            [[float(z.split(",")[0]), float(z.split(",")[1])] for z in self.azimuth.columns]
-        )
-        location = locations[
-            np.isclose(locations[:, 0], x_center_osgb) & np.isclose(locations[:, 1], y_center_osgb)
-        ]
-        # lets make sure there is atleast one
-        assert len(location) > 0
-        # Take the first location, and x and y coordinates are the first and center entries in
-        # this array.
-        location = location[0]
-        # make name of column to pull data from. The columns name will be about
-        # something like '22222.555,3333.6666'
-        name = x_y_to_name(x=location[0], y=location[1])
+        if not self.load_live:
 
-        del x_center_osgb, y_center_osgb
-        azimuth = self.azimuth.loc[start_dt:end_dt][name]
-        elevation = self.elevation.loc[start_dt:end_dt][name]
+            # The names of the columns get truncated when saving, therefore we need to look for the
+            # name of the columns near the location we are looking for
+            locations = np.array(
+                [[float(z.split(",")[0]), float(z.split(",")[1])] for z in self.azimuth.columns]
+            )
+            location = locations[
+                np.isclose(locations[:, 0], x_center_osgb)
+                & np.isclose(locations[:, 1], y_center_osgb)
+            ]
+            # lets make sure there is atleast one
+            assert len(location) > 0
+            # Take the first location, and x and y coordinates are the first and center entries in
+            # this array.
+            location = location[0]
+            # make name of column to pull data from. The columns name will be about
+            # something like '22222.555,3333.6666'
+            name = x_y_to_name(x=location[0], y=location[1])
+
+            del x_center_osgb, y_center_osgb
+            azimuth = self.azimuth.loc[start_dt:end_dt][name]
+            elevation = self.elevation.loc[start_dt:end_dt][name]
+
+        else:
+
+            latitude, longitude = osgb_to_lat_lon(x=x_center_osgb, y=y_center_osgb)
+
+            datestamps = pd.date_range(start=start_dt, end=end_dt, freq="5T").tolist()
+            azimuth_elevation = calculate_azimuth_and_elevation_angle(
+                latitude=latitude, longitude=longitude, datestamps=datestamps
+            )
+            azimuth = azimuth_elevation["azimuth"]
+            elevation = azimuth_elevation["elevation"]
 
         azimuth = azimuth.to_xarray().rename({"index": "time"})
         elevation = elevation.to_xarray().rename({"index": "time"})
@@ -97,7 +115,8 @@ class SunDataSource(DataSource):
 
         logger.info(f"Loading Sun data from {self.zarr_path}")
 
-        self.azimuth, self.elevation = load_from_zarr(zarr_path=self.zarr_path)
+        if not self.load_live:
+            self.azimuth, self.elevation = load_from_zarr(zarr_path=self.zarr_path)
 
     def get_locations(
         self, t0_datetimes_utc: pd.DatetimeIndex
@@ -112,13 +131,20 @@ class SunDataSource(DataSource):
         latitude = 51
         longitude = 0
 
+        if not self.load_live:
+            datestamps = self.elevation.index
+        else:
+            datestamps = pd.date_range(
+                datetime(2019, 1, 1), datetime(2019, 12, 31, 23, 55), freq="5T"
+            )
+
         # get elevation for all datetimes
         azimuth_elevation = calculate_azimuth_and_elevation_angle(
-            latitude=latitude, longitude=longitude, datestamps=self.elevation.index
+            latitude=latitude, longitude=longitude, datestamps=datestamps
         )
 
         # only select elevations > 10
-        mask = azimuth_elevation["elevation"] >= 10
+        mask = azimuth_elevation["elevation"] >= self.elevation_limit
 
         # create warnings, so we know how many datetimes will be dropped.
         # Should be slightly more than half as its night time 50% of the time
@@ -128,7 +154,7 @@ class SunDataSource(DataSource):
             f"out of {len(azimuth_elevation)} as elevation is < 10"
         )
 
-        datetimes = self.elevation[mask].index
+        datetimes = datestamps[mask]
 
         # Sun data is only for 2019, so to expand on these by
         # repeating data from 2014 to 2023
