@@ -1,14 +1,14 @@
-from datetime import timedelta
+""" Test for time utils functions """
 
 import numpy as np
 import pandas as pd
 import pytest
 
 from nowcasting_dataset import time as nd_time
-from nowcasting_dataset.time import FIVE_MINUTES, THIRTY_MINUTES
 
 
 def test_select_daylight_datetimes():
+    """Test day light filter works"""
     datetimes = pd.date_range("2020-01-01 00:00", "2020-01-02 00:00", freq="H")
     locations = [(0, 0), (20_000, 20_000)]
     daylight_datetimes = nd_time.select_daylight_datetimes(datetimes=datetimes, locations=locations)
@@ -16,8 +16,45 @@ def test_select_daylight_datetimes():
     np.testing.assert_array_equal(daylight_datetimes, correct_daylight_datetimes)
 
 
+def test_select_daylight_datetimes_dusk():
+    """Test day light filter works with keeping dusk and dawn extra hours"""
+    datetimes = pd.date_range("2020-01-01 00:00", "2020-01-02 00:00", freq="H")
+    locations = [(0, 0), (20_000, 20_000)]
+    daylight_datetimes = nd_time.select_daylight_datetimes(
+        datetimes=datetimes, locations=locations, keep_dawn_dusk_hours=2
+    )
+    correct_daylight_datetimes = pd.date_range("2020-01-01 07:00", "2020-01-01 18:00", freq="H")
+    np.testing.assert_array_equal(daylight_datetimes, correct_daylight_datetimes)
+
+
+def test_select_daylight_datetimes_dusk_non_gridded_date():
+    """Test day light filter works with keeping dusk and dawn extra hours
+
+    This is for non-gridded date.
+    This is to check that no extra datetimes are being returned
+    """
+    datetimes = pd.DatetimeIndex(
+        [
+            "2020-01-01 07:00",
+            "2020-01-01 16:00",
+            "2020-01-01 17:00",
+            "2020-01-01 18:00",
+            "2020-01-01 19:00",
+        ]
+    )
+    correct_daylight_datetimes = pd.DatetimeIndex(
+        ["2020-01-01 07:00", "2020-01-01 16:00", "2020-01-01 17:00", "2020-01-01 18:00"]
+    )
+    locations = [(0, 0), (20_000, 20_000)]
+    daylight_datetimes = nd_time.select_daylight_datetimes(
+        datetimes=datetimes, locations=locations, keep_dawn_dusk_hours=2
+    )
+    np.testing.assert_array_equal(daylight_datetimes, correct_daylight_datetimes)
+
+
 @pytest.mark.parametrize("min_seq_length", [2, 3, 12])
 def test_get_contiguous_time_periods_1_with_1_chunk(min_seq_length):
+    """Test getting continuous chunks of data with 1 chunk of data"""
     freq = pd.Timedelta(5, unit="minutes")
     dt_index = pd.date_range("2010-01-01", "2010-01-02", freq=freq)
     periods: pd.DataFrame = nd_time.get_contiguous_time_periods(
@@ -29,6 +66,7 @@ def test_get_contiguous_time_periods_1_with_1_chunk(min_seq_length):
 
 @pytest.mark.parametrize("min_seq_length", [2, 3, 12])
 def test_get_contiguous_time_periods_2_with_2_chunks(min_seq_length):
+    """Test getting continuous chunks of data with 2 chunks of data"""
     freq = pd.Timedelta(5, unit="minutes")
     dt_index1 = pd.date_range("2010-01-01", "2010-01-02", freq=freq)
     dt_index2 = pd.date_range("2010-02-01", "2010-02-02", freq=freq)
@@ -46,6 +84,7 @@ def test_get_contiguous_time_periods_2_with_2_chunks(min_seq_length):
 
 
 def test_intersection_of_2_dataframes_of_periods():
+    """Test intersection to two datetimes series"""
     dt = pd.Timestamp("2020-01-01 00:00")
     a = []
     b = []
@@ -110,6 +149,7 @@ def test_intersection_of_2_dataframes_of_periods():
 
 
 def test_intersection_of_multiple_dataframes_of_periods():
+    """Get intersection of multi timeseries"""
     dt = pd.Timestamp("2020-01-01 00:00")
 
     # a: |-----|
@@ -126,6 +166,7 @@ def test_intersection_of_multiple_dataframes_of_periods():
 
 
 def test_time_periods_to_datetime_index():
+    """Test changing time periods to datetime index"""
     dt = pd.Timestamp("2020-01-01 00:00")
     time_periods = pd.DataFrame(
         [
